# Abaqus CAE Display Preferences

Display preferences commands are used to edit the Abaqus/CAE preferences file, `abaqus_2021.gpr`.

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeGuiPrefs.CaeGuiPrefs
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeKerPrefs.CaeKerPrefs
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. automodule:: abaqus.AbaqusCAEDisplayPreferences.caePrefsAccess
        :members:
        :special-members: __init__
        :show-inheritance:
```
